//
//  GSPageView.m
//  wejointoo
//
//  Created by ijointoo on 2017/8/10.
//  Copyright © 2017年 demo. All rights reserved.
//

#import "GSPageView.h"
#import "GSToolView.h"
#import "UIView+JKPicker.h"

#define kScreenWidth [UIScreen mainScreen].bounds.size.width
#define kScreenHeight [UIScreen mainScreen].bounds.size.height

static CGFloat kToolViewHeight = 30;

@interface GSPageView ()<UIScrollViewDelegate,UITableViewDelegate,UITableViewDataSource,GSToolViewDelegate>


@property (nonatomic,strong)UIView *topView;
@property (nonatomic,strong)NSArray *titles;
@property (nonatomic,assign)CGFloat topViewHeight;
@property (nonatomic,strong)UIView *bannerView;
@property (nonatomic,strong)UIScrollView *scrollView;
@property (nonatomic,strong)NSMutableArray <UITableView *> *tableViews;
@property (nonatomic,assign)CGFloat contentOffsetY;
@property (nonatomic,strong)GSToolView *toolView;

@end

@implementation GSPageView

- (NSMutableArray<UITableView *> *)tableViews{
    if (!_tableViews) {
        _tableViews = [NSMutableArray new];
    }
    return _tableViews;
}
- (instancetype)initWithFrame:(CGRect)frame topView:(UIView *)topView titles:(NSArray *)titles{
    if (self = [super initWithFrame:frame]) {
        
        self.backgroundColor = [UIColor whiteColor];
        
        _topView = topView;
        _titles = titles;
        
        _topViewHeight = _topView.JKheight;
        _contentOffsetY = -_topViewHeight-kToolViewHeight;
        
        [self confignTableViews];
        
        [self confignTopViews];
    }
    return self;
}
- (void)confignTableViews{
    
    _scrollView = [[UIScrollView alloc]initWithFrame:CGRectMake(0, 0, kScreenWidth, self.JKheight)];
    _scrollView.contentSize = CGSizeMake(kScreenWidth * _titles.count, _scrollView.JKheight - 128);
    _scrollView.showsHorizontalScrollIndicator = NO;
    _scrollView.delegate = self;
    _scrollView.pagingEnabled = YES;
    _scrollView.bounces = NO;
    [self addSubview:_scrollView];
    
    
    for (int i = 0; i<_titles.count; i ++) {
        UITableView *tableView = [[UITableView alloc]initWithFrame:CGRectMake(i *kScreenWidth, -64, kScreenWidth, self.JKheight) style:UITableViewStylePlain];
        tableView.delegate = self;
        tableView.dataSource = self;
        tableView.tag = i;
        tableView.showsVerticalScrollIndicator = NO;
        [tableView addObserver:self forKeyPath:@"contentOffset" options:NSKeyValueObservingOptionNew|NSKeyValueObservingOptionOld context:nil];
        tableView.contentInset = UIEdgeInsetsMake(_topViewHeight + kToolViewHeight, 0, 0, 0);
        [_scrollView addSubview:tableView];
        [self.tableViews addObject:tableView];
    }
}
- (void)confignTopViews{
    
    _bannerView = [[UIView alloc]initWithFrame:CGRectMake(0, 0, kScreenWidth, _topViewHeight+kToolViewHeight)];
    [_bannerView addSubview:_topView];
    
    
    _toolView = [GSToolView gsToolViewWithTitleArray:_titles];
    _toolView.frame = CGRectMake(0, _topViewHeight, kScreenWidth, kToolViewHeight);
    _toolView.commonfontSize = 16;
    _toolView.highLightFontSize = 18;
    _toolView.tintColor = [UIColor redColor];
    _toolView.zhnDelegate = self;
    [_bannerView addSubview:_toolView];
    self.delegate2 = _toolView;
    
    
    [self addSubview:_bannerView];
}

#pragma mark - scrollView的代理
- (void)scrollViewDidScroll:(UIScrollView *)scrollView{
    if ([scrollView isEqual:_scrollView]) {
        for (UITableView *tableView in _tableViews) {
            if (tableView.contentOffset.y < self.contentOffsetY  ) {
                tableView.contentOffset = CGPointMake(0, self.contentOffsetY);
            }
            else if ([[_superVc.navigationController.navigationBar subviews] objectAtIndex:0].alpha  != 1){
                tableView.contentOffset = CGPointMake(0, self.contentOffsetY);
            }
        }
    }
}

- (void)scrollViewDidEndDecelerating:(UIScrollView *)scrollView{
    if ([scrollView isEqual:_scrollView]) {
        int currentIndex = scrollView.contentOffset.x / kScreenWidth;
        if ([self.delegate1 respondsToSelector:@selector(gsScrollHorizontalToIndex:)]) {
            [self.delegate1 gsScrollHorizontalToIndex:currentIndex];
        }
        if ([self.delegate2 respondsToSelector:@selector(gsScrollHorizontalToIndex:)]) {
            [self.delegate2 gsScrollHorizontalToIndex:currentIndex];
        }
    }
}
- (void)observeValueForKeyPath:(NSString *)keyPath ofObject:(id)object change:(NSDictionary<NSString *,id> *)change context:(void *)context{
    
    UITableView *getTableView = object;
    CGFloat delta = self.topViewHeight + kToolViewHeight + getTableView.contentOffset.y;
    if (delta < self.topViewHeight - 64) {
        self.bannerView.JKtop = - delta;
        self.contentOffsetY = getTableView.contentOffset.y;
        CGFloat scale = delta / (self.topViewHeight - 64);
        if ([self.delegate1 respondsToSelector:@selector(gsPageForNavcAlpha:)]) {
            [self.delegate1 gsPageForNavcAlpha:scale];
        }
        
    }else{
        if ([self.delegate1 respondsToSelector:@selector(gsPageForNavcAlpha:)]) {
            [self.delegate1 gsPageForNavcAlpha:1];
        }
        
        self.bannerView.JKtop = - (_topViewHeight - 64);
        self.contentOffsetY = - kToolViewHeight - 64;
    }
}

#pragma  mark  -  toolview的代理方法
- (void)gsToolViewSelectedIndex:(NSInteger)index animate:(BOOL)animate{
    
    for (UITableView *tableView in _tableViews) {
        if (tableView.contentOffset.y < self.contentOffsetY  ) {
            tableView.contentOffset = CGPointMake(0, self.contentOffsetY);
        }
        else if ([[_superVc.navigationController.navigationBar subviews] objectAtIndex:0].alpha  != 1){
            tableView.contentOffset = CGPointMake(0, self.contentOffsetY);
        }
    }
    CGRect needShowRect = CGRectMake(index * kScreenWidth, 0, kScreenWidth, self.JKheight - 128);
    [self.scrollView scrollRectToVisible:needShowRect animated:animate];
    
    if ([self.delegate1 respondsToSelector:@selector(gsScrollHorizontalToIndex:)]) {
        [self.delegate1 gsScrollHorizontalToIndex:index];
    }
}


- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView{
    return 2;
}
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return 10;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    
    UITableViewCell * cell = [[UITableViewCell alloc]init];
    cell.textLabel.text = [NSString stringWithFormat:@"%ld:%lu",tableView.tag,indexPath.row];
    return cell;
    
}
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    
    if ([self.delegate1 respondsToSelector:@selector(gsPageDidSelectedTableViewTag:cellPath:)]) {
        [self.delegate1 gsPageDidSelectedTableViewTag:tableView.tag cellPath:indexPath];
    }
    
//    _superVc.navigationController pushViewController:<#(nonnull UIViewController *)#> animated:<#(BOOL)#>
}
#pragma  mark - 移除监听
- (void)dealloc{
    for (UITableView *getTableView in self.tableViews) {
        [getTableView removeObserver:self forKeyPath:@"contentOffset" context:nil];
    }
}



/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
